package rotor

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Elements.ModuleType

A module for representing the concept of a module type, which is really a compound comprising a sum of structure types and functor types.

type _ sub_t =
  1. | ST : Base._structure_type sub_t
  2. | FT : Base._functor_type sub_t
    (*

    Module types can be either structure types or functor types.

    *)
include Compound_Sig with type 'a sub_t := 'a sub_t
val lift : 'a sub_t -> 'a Base.t
type _sub_t =
  1. | Ex : 'a sub_t -> _sub_t
val _lift : _sub_t -> Base._t
val type_of : _sub_t -> Module._sub_t
module type T0 = sig ... end
module Make_T0 (X : sig ... end) : sig ... end
module type T1 = sig ... end
module Make_T1 (X : sig ... end) : sig ... end